@@ -1,4 +1,4 @@
-class OriginMixin(object):
+class OriginMixin:
     def get_origin(self):
         return "{scheme}://{host}".format(
             scheme=self.request.scheme, host=self.request.get_host()
